# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/python/tools/api/generator/create_python_api.py script.
"""Operators for manipulating tensors.
"""

from __future__ import print_function as _print_function

from tensorflow.python import batch_to_space_nd
from tensorflow.python import gather_nd
from tensorflow.python import reshape
from tensorflow.python import reverse
from tensorflow.python import roll
from tensorflow.python import scatter_nd
from tensorflow.python import space_to_batch_nd
from tensorflow.python import tile

del _print_function
