# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/python/tools/api/generator/create_python_api.py script.
"""Public API for tf.queue namespace.
"""

from __future__ import print_function as _print_function

from tensorflow.python import FIFOQueue
from tensorflow.python import PaddingFIFOQueue
from tensorflow.python import PriorityQueue
from tensorflow.python import QueueBase
from tensorflow.python import RandomShuffleQueue

del _print_function
